Documentation
¶
Overview ¶
Package winornot (Win or Not) is yet another collection of helpers based on Windows API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckInstanceExist ¶
CheckInstanceExist indicates if one instance of the application is open.
func DisableConsoleExtendedEditMode ¶ added in v0.0.3
func DisableConsoleExtendedEditMode()
DisableConsoleExtendedEditMode disables mouse input from console window by disabling QUICK_EDIT_MODE and MOUSE_INPUT, it also disables the INSERT_MODE
func DisableConsoleInsertMode ¶ added in v0.0.3
func DisableConsoleInsertMode()
DisableConsoleInsertMode will overwrite the text after the current cursor location when text inputs are entered in the console window.
func DisableConsoleMouseInput ¶ added in v0.0.3
func DisableConsoleMouseInput()
DisableConsoleMouseInput disables the capute of mouse events in the console window.
func DisableConsoleQuickEditMode ¶ added in v0.0.3
func DisableConsoleQuickEditMode()
DisableConsoleQuickEditMode disables the user to use the mouse to select and edit text in the console window.
func EnableANSIControl ¶ added in v0.0.2
func EnableANSIControl()
EnableANSIControl lets Windows cmd.exe's and PowerShell's console support ANSI escape sequences. Control character sequences that control cursor movement, color/font mode, and other operations can be performed.
Types ¶
This section is empty.